.. _ablot:

*********************************
Step 6: Blotting the Median Image
*********************************

.. moduleauthor:: Warren Hack <help@stsci.edu>

.. automodule:: drizzlepac.ablot
   :members:
   :undoc-members:
